@@ -1,48 +1,39 @@
 from __future__ import annotations
 
 import warnings
-from typing import TYPE_CHECKING
-from typing import Any
-from typing import Callable
-from typing import Literal
-from typing import Sequence
+from typing import TYPE_CHECKING, Any, Callable, Literal, Sequence
 
 from narwhals._compliant import LazyExpr
 from narwhals._compliant.expr import DepthTrackingExpr
 from narwhals._dask.expr_dt import DaskExprDateTimeNamespace
 from narwhals._dask.expr_str import DaskExprStringNamespace
-from narwhals._dask.utils import add_row_index
-from narwhals._dask.utils import maybe_evaluate_expr
-from narwhals._dask.utils import narwhals_to_native_dtype
-from narwhals._expression_parsing import ExprKind
-from narwhals._expression_parsing import evaluate_output_names_and_aliases
+from narwhals._dask.utils import (
+    add_row_index,
+    maybe_evaluate_expr,
+    narwhals_to_native_dtype,
+)
+from narwhals._expression_parsing import ExprKind, evaluate_output_names_and_aliases
 from narwhals._pandas_like.utils import native_to_narwhals_dtype
-from narwhals.exceptions import ColumnNotFoundError
 from narwhals.exceptions import InvalidOperationError
-from narwhals.utils import Implementation
-from narwhals.utils import generate_temporary_column_name
-from narwhals.utils import not_implemented
+from narwhals.utils import Implementation, generate_temporary_column_name, not_implemented
 
 if TYPE_CHECKING:
     import dask.dataframe.dask_expr as dx
     from typing_extensions import Self
 
-    from narwhals._compliant.typing import AliasNames
-    from narwhals._compliant.typing import EvalNames
-    from narwhals._compliant.typing import EvalSeries
-    from narwhals._compliant.typing import ScalarKwargs
+    from narwhals._compliant.typing import AliasNames, EvalNames, EvalSeries, ScalarKwargs
     from narwhals._dask.dataframe import DaskLazyFrame
     from narwhals._dask.namespace import DaskNamespace
-    from narwhals._expression_parsing import ExprKind
-    from narwhals._expression_parsing import ExprMetadata
+    from narwhals._expression_parsing import ExprKind, ExprMetadata
     from narwhals.dtypes import DType
-    from narwhals.typing import FillNullStrategy
-    from narwhals.typing import NonNestedLiteral
-    from narwhals.typing import NumericLiteral
-    from narwhals.typing import RollingInterpolationMethod
-    from narwhals.typing import TemporalLiteral
-    from narwhals.utils import Version
-    from narwhals.utils import _FullContext
+    from narwhals.typing import (
+        FillNullStrategy,
+        NonNestedLiteral,
+        NumericLiteral,
+        RollingInterpolationMethod,
+        TemporalLiteral,
+    )
+    from narwhals.utils import Version, _FullContext
 
 
 class DaskExpr(
@@ -115,13 +106,9 @@ class DaskExpr(
                     for column_name in evaluate_column_names(df)
                 ]
             except KeyError as e:
-                missing_columns = [
-                    x for x in evaluate_column_names(df) if x not in df.columns
-                ]
-                raise ColumnNotFoundError.from_missing_and_available_column_names(
-                    missing_columns=missing_columns,
-                    available_columns=df.columns,
-                ) from e
+                if error := df._check_columns_exist(evaluate_column_names(df)):
+                    raise error from e
+                raise
 
         return cls(
             func,
@@ -194,109 +181,109 @@ class DaskExpr(
 
     def __add__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__add__(other), "__add__", other=other
+            lambda expr, other: expr.__add__(other), "__add__", other=other
         )
 
     def __sub__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__sub__(other), "__sub__", other=other
+            lambda expr, other: expr.__sub__(other), "__sub__", other=other
         )
 
     def __rsub__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: other - _input, "__rsub__", other=other
+            lambda expr, other: other - expr, "__rsub__", other=other
         ).alias("literal")
 
     def __mul__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__mul__(other), "__mul__", other=other
+            lambda expr, other: expr.__mul__(other), "__mul__", other=other
         )
 
     def __truediv__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__truediv__(other), "__truediv__", other=other
+            lambda expr, other: expr.__truediv__(other), "__truediv__", other=other
         )
 
     def __rtruediv__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: other / _input, "__rtruediv__", other=other
+            lambda expr, other: other / expr, "__rtruediv__", other=other
         ).alias("literal")
 
     def __floordiv__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__floordiv__(other), "__floordiv__", other=other
+            lambda expr, other: expr.__floordiv__(other), "__floordiv__", other=other
         )
 
     def __rfloordiv__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: other // _input, "__rfloordiv__", other=other
+            lambda expr, other: other // expr, "__rfloordiv__", other=other
         ).alias("literal")
 
     def __pow__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__pow__(other), "__pow__", other=other
+            lambda expr, other: expr.__pow__(other), "__pow__", other=other
         )
 
     def __rpow__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: other**_input, "__rpow__", other=other
+            lambda expr, other: other**expr, "__rpow__", other=other
         ).alias("literal")
 
     def __mod__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__mod__(other), "__mod__", other=other
+            lambda expr, other: expr.__mod__(other), "__mod__", other=other
         )
 
     def __rmod__(self, other: Any) -> Self:
         return self._with_callable(
-            lambda _input, other: other % _input, "__rmod__", other=other
+            lambda expr, other: other % expr, "__rmod__", other=other
         ).alias("literal")
 
     def __eq__(self, other: DaskExpr) -> Self:  # type: ignore[override]
         return self._with_callable(
-            lambda _input, other: _input.__eq__(other), "__eq__", other=other
+            lambda expr, other: expr.__eq__(other), "__eq__", other=other
         )
 
     def __ne__(self, other: DaskExpr) -> Self:  # type: ignore[override]
         return self._with_callable(
-            lambda _input, other: _input.__ne__(other), "__ne__", other=other
+            lambda expr, other: expr.__ne__(other), "__ne__", other=other
         )
 
     def __ge__(self, other: DaskExpr | Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__ge__(other), "__ge__", other=other
+            lambda expr, other: expr.__ge__(other), "__ge__", other=other
         )
 
     def __gt__(self, other: DaskExpr) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__gt__(other), "__gt__", other=other
+            lambda expr, other: expr.__gt__(other), "__gt__", other=other
         )
 
     def __le__(self, other: DaskExpr) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__le__(other), "__le__", other=other
+            lambda expr, other: expr.__le__(other), "__le__", other=other
         )
 
     def __lt__(self, other: DaskExpr) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__lt__(other), "__lt__", other=other
+            lambda expr, other: expr.__lt__(other), "__lt__", other=other
         )
 
     def __and__(self, other: DaskExpr | Any) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__and__(other), "__and__", other=other
+            lambda expr, other: expr.__and__(other), "__and__", other=other
         )
 
     def __or__(self, other: DaskExpr) -> Self:
         return self._with_callable(
-            lambda _input, other: _input.__or__(other), "__or__", other=other
+            lambda expr, other: expr.__or__(other), "__or__", other=other
         )
 
     def __invert__(self) -> Self:
-        return self._with_callable(lambda _input: _input.__invert__(), "__invert__")
+        return self._with_callable(lambda expr: expr.__invert__(), "__invert__")
 
     def mean(self) -> Self:
-        return self._with_callable(lambda _input: _input.mean().to_series(), "mean")
+        return self._with_callable(lambda expr: expr.mean().to_series(), "mean")
 
     def median(self) -> Self:
         from narwhals.exceptions import InvalidOperationError
@@ -311,30 +298,30 @@ class DaskExpr(
         return self._with_callable(func, "median")
 
     def min(self) -> Self:
-        return self._with_callable(lambda _input: _input.min().to_series(), "min")
+        return self._with_callable(lambda expr: expr.min().to_series(), "min")
 
     def max(self) -> Self:
-        return self._with_callable(lambda _input: _input.max().to_series(), "max")
+        return self._with_callable(lambda expr: expr.max().to_series(), "max")
 
     def std(self, ddof: int) -> Self:
         return self._with_callable(
-            lambda _input: _input.std(ddof=ddof).to_series(),
+            lambda expr: expr.std(ddof=ddof).to_series(),
             "std",
             scalar_kwargs={"ddof": ddof},
         )
 
     def var(self, ddof: int) -> Self:
         return self._with_callable(
-            lambda _input: _input.var(ddof=ddof).to_series(),
+            lambda expr: expr.var(ddof=ddof).to_series(),
             "var",
             scalar_kwargs={"ddof": ddof},
         )
 
     def skew(self) -> Self:
-        return self._with_callable(lambda _input: _input.skew().to_series(), "skew")
+        return self._with_callable(lambda expr: expr.skew().to_series(), "skew")
 
     def shift(self, n: int) -> Self:
-        return self._with_callable(lambda _input: _input.shift(n), "shift")
+        return self._with_callable(lambda expr: expr.shift(n), "shift")
 
     def cum_sum(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
@@ -342,7 +329,7 @@ class DaskExpr(
             msg = "`cum_sum(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._with_callable(lambda _input: _input.cumsum(), "cum_sum")
+        return self._with_callable(lambda expr: expr.cumsum(), "cum_sum")
 
     def cum_count(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
@@ -350,7 +337,7 @@ class DaskExpr(
             raise NotImplementedError(msg)
 
         return self._with_callable(
-            lambda _input: (~_input.isna()).astype(int).cumsum(), "cum_count"
+            lambda expr: (~expr.isna()).astype(int).cumsum(), "cum_count"
         )
 
     def cum_min(self, *, reverse: bool) -> Self:
@@ -358,25 +345,25 @@ class DaskExpr(
             msg = "`cum_min(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._with_callable(lambda _input: _input.cummin(), "cum_min")
+        return self._with_callable(lambda expr: expr.cummin(), "cum_min")
 
     def cum_max(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
             msg = "`cum_max(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._with_callable(lambda _input: _input.cummax(), "cum_max")
+        return self._with_callable(lambda expr: expr.cummax(), "cum_max")
 
     def cum_prod(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
             msg = "`cum_prod(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._with_callable(lambda _input: _input.cumprod(), "cum_prod")
+        return self._with_callable(lambda expr: expr.cumprod(), "cum_prod")
 
     def rolling_sum(self, window_size: int, *, min_samples: int, center: bool) -> Self:
         return self._with_callable(
-            lambda _input: _input.rolling(
+            lambda expr: expr.rolling(
                 window=window_size, min_periods=min_samples, center=center
             ).sum(),
             "rolling_sum",
@@ -384,7 +371,7 @@ class DaskExpr(
 
     def rolling_mean(self, window_size: int, *, min_samples: int, center: bool) -> Self:
         return self._with_callable(
-            lambda _input: _input.rolling(
+            lambda expr: expr.rolling(
                 window=window_size, min_periods=min_samples, center=center
             ).mean(),
             "rolling_mean",
@@ -395,7 +382,7 @@ class DaskExpr(
     ) -> Self:
         if ddof == 1:
             return self._with_callable(
-                lambda _input: _input.rolling(
+                lambda expr: expr.rolling(
                     window=window_size, min_periods=min_samples, center=center
                 ).var(),
                 "rolling_var",
@@ -409,7 +396,7 @@ class DaskExpr(
     ) -> Self:
         if ddof == 1:
             return self._with_callable(
-                lambda _input: _input.rolling(
+                lambda expr: expr.rolling(
                     window=window_size, min_periods=min_samples, center=center
                 ).std(),
                 "rolling_std",
@@ -419,26 +406,26 @@ class DaskExpr(
             raise NotImplementedError(msg)
 
     def sum(self) -> Self:
-        return self._with_callable(lambda _input: _input.sum().to_series(), "sum")
+        return self._with_callable(lambda expr: expr.sum().to_series(), "sum")
 
     def count(self) -> Self:
-        return self._with_callable(lambda _input: _input.count().to_series(), "count")
+        return self._with_callable(lambda expr: expr.count().to_series(), "count")
 
     def round(self, decimals: int) -> Self:
-        return self._with_callable(lambda _input: _input.round(decimals), "round")
+        return self._with_callable(lambda expr: expr.round(decimals), "round")
 
     def unique(self) -> Self:
-        return self._with_callable(lambda _input: _input.unique(), "unique")
+        return self._with_callable(lambda expr: expr.unique(), "unique")
 
     def drop_nulls(self) -> Self:
-        return self._with_callable(lambda _input: _input.dropna(), "drop_nulls")
+        return self._with_callable(lambda expr: expr.dropna(), "drop_nulls")
 
     def abs(self) -> Self:
-        return self._with_callable(lambda _input: _input.abs(), "abs")
+        return self._with_callable(lambda expr: expr.abs(), "abs")
 
     def all(self) -> Self:
         return self._with_callable(
-            lambda _input: _input.all(
+            lambda expr: expr.all(
                 axis=None, skipna=True, split_every=False, out=None
             ).to_series(),
             "all",
@@ -446,7 +433,7 @@ class DaskExpr(
 
     def any(self) -> Self:
         return self._with_callable(
-            lambda _input: _input.any(axis=0, skipna=True, split_every=False).to_series(),
+            lambda expr: expr.any(axis=0, skipna=True, split_every=False).to_series(),
             "any",
         )
 
@@ -456,14 +443,14 @@ class DaskExpr(
         strategy: FillNullStrategy | None,
         limit: int | None,
     ) -> Self:
-        def func(_input: dx.Series) -> dx.Series:
+        def func(expr: dx.Series) -> dx.Series:
             if value is not None:
-                res_ser = _input.fillna(value)
+                res_ser = expr.fillna(value)
             else:
                 res_ser = (
-                    _input.ffill(limit=limit)
+                    expr.ffill(limit=limit)
                     if strategy == "forward"
-                    else _input.bfill(limit=limit)
+                    else expr.bfill(limit=limit)
                 )
             return res_ser
 
@@ -475,7 +462,7 @@ class DaskExpr(
         upper_bound: Self | NumericLiteral | TemporalLiteral | None,
     ) -> Self:
         return self._with_callable(
-            lambda _input, lower_bound, upper_bound: _input.clip(
+            lambda expr, lower_bound, upper_bound: expr.clip(
                 lower=lower_bound, upper=upper_bound
             ),
             "clip",
@@ -484,41 +471,41 @@ class DaskExpr(
         )
 
     def diff(self) -> Self:
-        return self._with_callable(lambda _input: _input.diff(), "diff")
+        return self._with_callable(lambda expr: expr.diff(), "diff")
 
     def n_unique(self) -> Self:
         return self._with_callable(
-            lambda _input: _input.nunique(dropna=False).to_series(), "n_unique"
+            lambda expr: expr.nunique(dropna=False).to_series(), "n_unique"
         )
 
     def is_null(self) -> Self:
-        return self._with_callable(lambda _input: _input.isna(), "is_null")
+        return self._with_callable(lambda expr: expr.isna(), "is_null")
 
     def is_nan(self) -> Self:
-        def func(_input: dx.Series) -> dx.Series:
+        def func(expr: dx.Series) -> dx.Series:
             dtype = native_to_narwhals_dtype(
-                _input.dtype, self._version, self._implementation
+                expr.dtype, self._version, self._implementation
             )
             if dtype.is_numeric():
-                return _input != _input  # pyright: ignore[reportReturnType] # noqa: PLR0124
+                return expr != expr  # pyright: ignore[reportReturnType] # noqa: PLR0124
             msg = f"`.is_nan` only supported for numeric dtypes and not {dtype}, did you mean `.is_null`?"
             raise InvalidOperationError(msg)
 
         return self._with_callable(func, "is_null")
 
     def len(self) -> Self:
-        return self._with_callable(lambda _input: _input.size.to_series(), "len")
+        return self._with_callable(lambda expr: expr.size.to_series(), "len")
 
     def quantile(
         self, quantile: float, interpolation: RollingInterpolationMethod
     ) -> Self:
         if interpolation == "linear":
 
-            def func(_input: dx.Series, quantile: float) -> dx.Series:
-                if _input.npartitions > 1:
+            def func(expr: dx.Series, quantile: float) -> dx.Series:
+                if expr.npartitions > 1:
                     msg = "`Expr.quantile` is not supported for Dask backend with multiple partitions."
                     raise NotImplementedError(msg)
-                return _input.quantile(
+                return expr.quantile(
                     q=quantile, method="dask"
                 ).to_series()  # pragma: no cover
 
@@ -528,11 +515,11 @@ class DaskExpr(
             raise NotImplementedError(msg)
 
     def is_first_distinct(self) -> Self:
-        def func(_input: dx.Series) -> dx.Series:
-            _name = _input.name
+        def func(expr: dx.Series) -> dx.Series:
+            _name = expr.name
             col_token = generate_temporary_column_name(n_bytes=8, columns=[_name])
             frame = add_row_index(
-                _input.to_frame(), col_token, self._backend_version, self._implementation
+                expr.to_frame(), col_token, self._backend_version, self._implementation
             )
             first_distinct_index = frame.groupby(_name).agg({col_token: "min"})[col_token]
             return frame[col_token].isin(first_distinct_index)
@@ -540,11 +527,11 @@ class DaskExpr(
         return self._with_callable(func, "is_first_distinct")
 
     def is_last_distinct(self) -> Self:
-        def func(_input: dx.Series) -> dx.Series:
-            _name = _input.name
+        def func(expr: dx.Series) -> dx.Series:
+            _name = expr.name
             col_token = generate_temporary_column_name(n_bytes=8, columns=[_name])
             frame = add_row_index(
-                _input.to_frame(), col_token, self._backend_version, self._implementation
+                expr.to_frame(), col_token, self._backend_version, self._implementation
             )
             last_distinct_index = frame.groupby(_name).agg({col_token: "max"})[col_token]
             return frame[col_token].isin(last_distinct_index)
@@ -552,10 +539,10 @@ class DaskExpr(
         return self._with_callable(func, "is_last_distinct")
 
     def is_unique(self) -> Self:
-        def func(_input: dx.Series) -> dx.Series:
-            _name = _input.name
+        def func(expr: dx.Series) -> dx.Series:
+            _name = expr.name
             return (
-                _input.to_frame()
+                expr.to_frame()
                 .groupby(_name, dropna=False)
                 .transform("size", meta=(_name, int))
                 == 1
@@ -564,18 +551,14 @@ class DaskExpr(
         return self._with_callable(func, "is_unique")
 
     def is_in(self, other: Any) -> Self:
-        return self._with_callable(lambda _input: _input.isin(other), "is_in")
+        return self._with_callable(lambda expr: expr.isin(other), "is_in")
 
     def null_count(self) -> Self:
         return self._with_callable(
-            lambda _input: _input.isna().sum().to_series(), "null_count"
+            lambda expr: expr.isna().sum().to_series(), "null_count"
         )
 
-    def over(
-        self,
-        partition_by: Sequence[str],
-        order_by: Sequence[str] | None,
-    ) -> Self:
+    def over(self, partition_by: Sequence[str], order_by: Sequence[str] | None) -> Self:
         # pandas is a required dependency of dask so it's safe to import this
         from narwhals._pandas_like.group_by import PandasLikeGroupBy
 
@@ -647,9 +630,9 @@ class DaskExpr(
         )
 
     def cast(self, dtype: DType | type[DType]) -> Self:
-        def func(_input: dx.Series) -> dx.Series:
+        def func(expr: dx.Series) -> dx.Series:
             native_dtype = narwhals_to_native_dtype(dtype, self._version)
-            return _input.astype(native_dtype)
+            return expr.astype(native_dtype)
 
         return self._with_callable(func, "cast")
 
@@ -661,8 +644,8 @@ class DaskExpr(
     def log(self, base: float) -> Self:
         import dask.array as da
 
-        def _log(_input: dx.Series) -> dx.Series:
-            return da.log(_input) / da.log(base)
+        def _log(expr: dx.Series) -> dx.Series:
+            return da.log(expr) / da.log(base)
 
         return self._with_callable(_log, "log")
 
