@@ -3,64 +3,62 @@ from __future__ import annotations
 import platform
 import sys
 from importlib.metadata import version
-from typing import TYPE_CHECKING
-from typing import Any
-from typing import Iterable
-from typing import Literal
-from typing import Mapping
-from typing import Sequence
-from typing import cast
+from typing import TYPE_CHECKING, Any, Iterable, Literal, Mapping, Sequence, cast
 
-from narwhals._expression_parsing import ExprKind
-from narwhals._expression_parsing import ExprMetadata
-from narwhals._expression_parsing import apply_n_ary_operation
-from narwhals._expression_parsing import check_expressions_preserve_length
-from narwhals._expression_parsing import combine_metadata
-from narwhals._expression_parsing import extract_compliant
-from narwhals._expression_parsing import is_scalar_like
-from narwhals.dependencies import is_narwhals_series
-from narwhals.dependencies import is_numpy_array
-from narwhals.dependencies import is_numpy_array_2d
-from narwhals.dependencies import is_pyarrow_table
+from narwhals._expression_parsing import (
+    ExprKind,
+    ExprMetadata,
+    apply_n_ary_operation,
+    check_expressions_preserve_length,
+    combine_metadata,
+    extract_compliant,
+    is_scalar_like,
+)
+from narwhals.dependencies import (
+    is_narwhals_series,
+    is_numpy_array,
+    is_numpy_array_2d,
+    is_pyarrow_table,
+)
 from narwhals.exceptions import InvalidOperationError
 from narwhals.expr import Expr
-from narwhals.translate import from_native
-from narwhals.translate import to_native
-from narwhals.utils import Implementation
-from narwhals.utils import Version
-from narwhals.utils import deprecate_native_namespace
-from narwhals.utils import flatten
-from narwhals.utils import is_compliant_expr
-from narwhals.utils import is_eager_allowed
-from narwhals.utils import is_sequence_but_not_str
-from narwhals.utils import parse_version
-from narwhals.utils import supports_arrow_c_stream
-from narwhals.utils import validate_laziness
+from narwhals.translate import from_native, to_native
+from narwhals.utils import (
+    Implementation,
+    Version,
+    deprecate_native_namespace,
+    flatten,
+    is_compliant_expr,
+    is_eager_allowed,
+    is_sequence_but_not_str,
+    parse_version,
+    supports_arrow_c_stream,
+    validate_laziness,
+)
 
 if TYPE_CHECKING:
     from types import ModuleType
 
-    from typing_extensions import TypeAlias
-    from typing_extensions import TypeIs
+    from typing_extensions import TypeAlias, TypeIs
 
-    from narwhals._compliant import CompliantExpr
-    from narwhals._compliant import CompliantNamespace
+    from narwhals._compliant import CompliantExpr, CompliantNamespace
     from narwhals._translate import IntoArrowTable
-    from narwhals.dataframe import DataFrame
-    from narwhals.dataframe import LazyFrame
+    from narwhals.dataframe import DataFrame, LazyFrame
     from narwhals.dtypes import DType
     from narwhals.schema import Schema
     from narwhals.series import Series
-    from narwhals.typing import ConcatMethod
-    from narwhals.typing import FrameT
-    from narwhals.typing import IntoExpr
-    from narwhals.typing import IntoSeriesT
-    from narwhals.typing import NativeFrame
-    from narwhals.typing import NativeLazyFrame
-    from narwhals.typing import NativeSeries
-    from narwhals.typing import NonNestedLiteral
-    from narwhals.typing import _1DArray
-    from narwhals.typing import _2DArray
+    from narwhals.typing import (
+        ConcatMethod,
+        FrameT,
+        IntoExpr,
+        IntoSeriesT,
+        NativeFrame,
+        NativeLazyFrame,
+        NativeSeries,
+        NonNestedLiteral,
+        _1DArray,
+        _2DArray,
+    )
 
     _IntoSchema: TypeAlias = "Mapping[str, DType] | Schema | Sequence[str] | None"
 
@@ -166,7 +164,7 @@ def concat(items: Iterable[FrameT], *, how: ConcatMethod = "vertical") -> FrameT
         raise InvalidOperationError(msg)
     plx = first_item.__narwhals_namespace__()
     return first_item._with_compliant(
-        plx.concat([df._compliant_frame for df in items], how=how),
+        plx.concat([df._compliant_frame for df in items], how=how)
     )
 
 
@@ -222,7 +220,7 @@ def new_series(
         └─────────────────────┘
     """
     backend = cast("ModuleType | Implementation | str", backend)
-    return _new_series_impl(name, values, dtype, backend=backend, version=Version.MAIN)
+    return _new_series_impl(name, values, dtype, backend=backend)
 
 
 def _new_series_impl(
@@ -231,24 +229,28 @@ def _new_series_impl(
     dtype: DType | type[DType] | None = None,
     *,
     backend: ModuleType | Implementation | str,
-    version: Version,
 ) -> Series[Any]:
     implementation = Implementation.from_backend(backend)
     if is_eager_allowed(implementation):
-        ns = version.namespace.from_backend(implementation).compliant
+        ns = Version.MAIN.namespace.from_backend(implementation).compliant
         series = ns._series.from_iterable(values, name=name, context=ns, dtype=dtype)
         return series.to_narwhals()
-    elif implementation is Implementation.DASK:  # pragma: no cover
-        msg = "Dask support in Narwhals is lazy-only, so `new_series` is not supported"
-        raise NotImplementedError(msg)
-    else:  # pragma: no cover
-        native_namespace = implementation.to_native_namespace()
+    elif implementation is Implementation.UNKNOWN:  # pragma: no cover
+        _native_namespace = implementation.to_native_namespace()
         try:
-            native_series: NativeSeries = native_namespace.new_series(name, values, dtype)
+            native_series: NativeSeries = _native_namespace.new_series(
+                name, values, dtype
+            )
             return from_native(native_series, series_only=True).alias(name)
         except AttributeError as e:
             msg = "Unknown namespace is expected to implement `new_series` constructor."
             raise AttributeError(msg) from e
+    msg = (
+        f"{implementation} support in Narwhals is lazy-only, but `new_series` is an eager-only function.\n\n"
+        "Hint: you may want to use an eager backend and then call `.lazy`, e.g.:\n\n"
+        f"    nw.new_series('a', [1,2,3], backend='pyarrow').to_frame().lazy('{implementation}')"
+    )
+    raise ValueError(msg)
 
 
 @deprecate_native_namespace(warn_version="1.26.0")
@@ -305,16 +307,6 @@ def from_dict(
         |     1  2  4      |
         └──────────────────┘
     """
-    return _from_dict_impl(data, schema, backend=backend, version=Version.MAIN)
-
-
-def _from_dict_impl(
-    data: Mapping[str, Any],
-    schema: Mapping[str, DType] | Schema | None,
-    *,
-    backend: ModuleType | Implementation | str | None,
-    version: Version,
-) -> DataFrame[Any]:
     if not data:
         msg = "from_dict cannot be called with empty dictionary"
         raise ValueError(msg)
@@ -322,22 +314,22 @@ def _from_dict_impl(
         data, backend = _from_dict_no_backend(data)
     implementation = Implementation.from_backend(backend)
     if is_eager_allowed(implementation):
-        ns = version.namespace.from_backend(implementation).compliant
+        ns = Version.MAIN.namespace.from_backend(implementation).compliant
         return ns._dataframe.from_dict(data, schema=schema, context=ns).to_narwhals()
     elif implementation is Implementation.UNKNOWN:  # pragma: no cover
-        native_namespace = implementation.to_native_namespace()
+        _native_namespace = implementation.to_native_namespace()
         try:
             # implementation is UNKNOWN, Narwhals extension using this feature should
             # implement `from_dict` function in the top-level namespace.
-            native_frame: NativeFrame = native_namespace.from_dict(data, schema=schema)
+            native_frame: NativeFrame = _native_namespace.from_dict(data, schema=schema)
         except AttributeError as e:
             msg = "Unknown namespace is expected to implement `from_dict` function."
             raise AttributeError(msg) from e
         return from_native(native_frame, eager_only=True)
     msg = (
-        f"Unsupported `backend` value.\nExpected one of "
-        f"{Implementation.POLARS, Implementation.PANDAS, Implementation.PYARROW, Implementation.MODIN, Implementation.CUDF} "
-        f"or None, got: {implementation}."
+        f"{implementation} support in Narwhals is lazy-only, but `from_dict` is an eager-only function.\n\n"
+        "Hint: you may want to use an eager backend and then call `.lazy`, e.g.:\n\n"
+        f"    nw.from_dict({{'a': [1, 2]}}, backend='pyarrow').lazy('{implementation}')"
     )
     raise ValueError(msg)
 
@@ -416,16 +408,6 @@ def from_numpy(
         └──────────────────┘
     """
     backend = cast("ModuleType | Implementation | str", backend)
-    return _from_numpy_impl(data, schema, backend=backend, version=Version.MAIN)
-
-
-def _from_numpy_impl(
-    data: _2DArray,
-    schema: Mapping[str, DType] | Schema | Sequence[str] | None = None,
-    *,
-    backend: ModuleType | Implementation | str,
-    version: Version,
-) -> DataFrame[Any]:
     if not is_numpy_array_2d(data):
         msg = "`from_numpy` only accepts 2D numpy arrays"
         raise ValueError(msg)
@@ -438,18 +420,24 @@ def _from_numpy_impl(
         raise TypeError(msg)
     implementation = Implementation.from_backend(backend)
     if is_eager_allowed(implementation):
-        ns = version.namespace.from_backend(implementation).compliant
+        ns = Version.MAIN.namespace.from_backend(implementation).compliant
         return ns.from_numpy(data, schema).to_narwhals()
-    else:  # pragma: no cover
-        native_namespace = implementation.to_native_namespace()
+    elif implementation is Implementation.UNKNOWN:  # pragma: no cover
+        _native_namespace = implementation.to_native_namespace()
         try:
             # implementation is UNKNOWN, Narwhals extension using this feature should
             # implement `from_numpy` function in the top-level namespace.
-            native_frame: NativeFrame = native_namespace.from_numpy(data, schema=schema)
+            native_frame: NativeFrame = _native_namespace.from_numpy(data, schema=schema)
         except AttributeError as e:
             msg = "Unknown namespace is expected to implement `from_numpy` function."
             raise AttributeError(msg) from e
         return from_native(native_frame, eager_only=True)
+    msg = (
+        f"{implementation} support in Narwhals is lazy-only, but `from_numpy` is an eager-only function.\n\n"
+        "Hint: you may want to use an eager backend and then call `.lazy`, e.g.:\n\n"
+        f"    nw.from_numpy(arr, backend='pyarrow').lazy('{implementation}')"
+    )
+    raise ValueError(msg)
 
 
 def _is_into_schema(obj: Any) -> TypeIs[_IntoSchema]:
@@ -512,32 +500,29 @@ def from_arrow(
         └──────────────────┘
     """
     backend = cast("ModuleType | Implementation | str", backend)
-    return _from_arrow_impl(native_frame, backend=backend, version=Version.MAIN)
-
-
-def _from_arrow_impl(
-    data: IntoArrowTable,
-    *,
-    backend: ModuleType | Implementation | str,
-    version: Version,
-) -> DataFrame[Any]:
-    if not (supports_arrow_c_stream(data) or is_pyarrow_table(data)):
-        msg = f"Given object of type {type(data)} does not support PyCapsule interface"
+    if not (supports_arrow_c_stream(native_frame) or is_pyarrow_table(native_frame)):
+        msg = f"Given object of type {type(native_frame)} does not support PyCapsule interface"
         raise TypeError(msg)
     implementation = Implementation.from_backend(backend)
     if is_eager_allowed(implementation):
-        ns = version.namespace.from_backend(implementation).compliant
-        return ns._dataframe.from_arrow(data, context=ns).to_narwhals()
-    else:  # pragma: no cover
-        native_namespace = implementation.to_native_namespace()
+        ns = Version.MAIN.namespace.from_backend(implementation).compliant
+        return ns._dataframe.from_arrow(native_frame, context=ns).to_narwhals()
+    elif implementation is Implementation.UNKNOWN:  # pragma: no cover
+        _native_namespace = implementation.to_native_namespace()
         try:
             # implementation is UNKNOWN, Narwhals extension using this feature should
             # implement PyCapsule support
-            native_frame: NativeFrame = native_namespace.DataFrame(data)
+            native: NativeFrame = _native_namespace.DataFrame(native_frame)
         except AttributeError as e:
             msg = "Unknown namespace is expected to implement `DataFrame` class which accepts object which supports PyCapsule Interface."
             raise AttributeError(msg) from e
-        return from_native(native_frame, eager_only=True)
+        return from_native(native, eager_only=True)
+    msg = (
+        f"{implementation} support in Narwhals is lazy-only, but `from_arrow` is an eager-only function.\n\n"
+        "Hint: you may want to use an eager backend and then call `.lazy`, e.g.:\n\n"
+        f"    nw.from_arrow(df, backend='pyarrow').lazy('{implementation}')"
+    )
+    raise ValueError(msg)
 
 
 def _get_sys_info() -> dict[str, str]:
@@ -574,8 +559,7 @@ def _get_deps_info() -> dict[str, str]:
     Returns:
         Mapping from dependency to version.
     """
-    from importlib.metadata import PackageNotFoundError
-    from importlib.metadata import version
+    from importlib.metadata import PackageNotFoundError, version
 
     from narwhals import __version__
 
@@ -633,7 +617,7 @@ def read_csv(
     source: str,
     *,
     backend: ModuleType | Implementation | str | None = None,
-    native_namespace: ModuleType | None = None,  # noqa: ARG001
+    native_namespace: ModuleType | None = None,
     **kwargs: Any,
 ) -> DataFrame[Any]:
     """Read a CSV file into a DataFrame.
@@ -673,12 +657,6 @@ def read_csv(
         └──────────────────┘
     """
     backend = cast("ModuleType | Implementation | str", backend)
-    return _read_csv_impl(source, backend=backend, **kwargs)
-
-
-def _read_csv_impl(
-    source: str, *, backend: ModuleType | Implementation | str, **kwargs: Any
-) -> DataFrame[Any]:
     eager_backend = Implementation.from_backend(backend)
     native_namespace = eager_backend.to_native_namespace()
     native_frame: NativeFrame
@@ -709,7 +687,7 @@ def scan_csv(
     source: str,
     *,
     backend: ModuleType | Implementation | str | None = None,
-    native_namespace: ModuleType | None = None,  # noqa: ARG001
+    native_namespace: ModuleType | None = None,
     **kwargs: Any,
 ) -> LazyFrame[Any]:
     """Lazily read from a CSV file.
@@ -755,12 +733,6 @@ def scan_csv(
         └─────────┴───────┘
     """
     backend = cast("ModuleType | Implementation | str", backend)
-    return _scan_csv_impl(source, backend=backend, **kwargs)
-
-
-def _scan_csv_impl(
-    source: str, *, backend: ModuleType | Implementation | str, **kwargs: Any
-) -> LazyFrame[Any]:
     implementation = Implementation.from_backend(backend)
     native_namespace = implementation.to_native_namespace()
     native_frame: NativeFrame | NativeLazyFrame
@@ -809,7 +781,7 @@ def read_parquet(
     source: str,
     *,
     backend: ModuleType | Implementation | str | None = None,
-    native_namespace: ModuleType | None = None,  # noqa: ARG001
+    native_namespace: ModuleType | None = None,
     **kwargs: Any,
 ) -> DataFrame[Any]:
     """Read into a DataFrame from a parquet file.
@@ -854,12 +826,6 @@ def read_parquet(
         └──────────────────┘
     """
     backend = cast("ModuleType | Implementation | str", backend)
-    return _read_parquet_impl(source, backend=backend, **kwargs)
-
-
-def _read_parquet_impl(
-    source: str, *, backend: ModuleType | Implementation | str, **kwargs: Any
-) -> DataFrame[Any]:
     implementation = Implementation.from_backend(backend)
     native_namespace = implementation.to_native_namespace()
     native_frame: NativeFrame
@@ -892,7 +858,7 @@ def scan_parquet(
     source: str,
     *,
     backend: ModuleType | Implementation | str | None = None,
-    native_namespace: ModuleType | None = None,  # noqa: ARG001
+    native_namespace: ModuleType | None = None,
     **kwargs: Any,
 ) -> LazyFrame[Any]:
     """Lazily read from a parquet file.
@@ -965,12 +931,6 @@ def scan_parquet(
         └──────────────────┘
     """
     backend = cast("ModuleType | Implementation | str", backend)
-    return _scan_parquet_impl(source, backend=backend, **kwargs)
-
-
-def _scan_parquet_impl(
-    source: str, *, backend: ModuleType | Implementation | str, **kwargs: Any
-) -> LazyFrame[Any]:
     implementation = Implementation.from_backend(backend)
     native_namespace = implementation.to_native_namespace()
     native_frame: NativeFrame | NativeLazyFrame
@@ -1724,11 +1684,7 @@ def mean_horizontal(*exprs: IntoExpr | Iterable[IntoExpr]) -> Expr:
         >>> import pyarrow as pa
         >>> import narwhals as nw
         >>>
-        >>> data = {
-        ...     "a": [1, 8, 3],
-        ...     "b": [4, 5, None],
-        ...     "c": ["x", "y", "z"],
-        ... }
+        >>> data = {"a": [1, 8, 3], "b": [4, 5, None], "c": ["x", "y", "z"]}
         >>> df_native = pa.table(data)
 
         We define a dataframe-agnostic function that computes the horizontal mean of "a"
@@ -1791,12 +1747,7 @@ def concat_str(
         >>> (
         ...     nw.from_native(df_native).select(
         ...         nw.concat_str(
-        ...             [
-        ...                 nw.col("a") * 2,
-        ...                 nw.col("b"),
-        ...                 nw.col("c"),
-        ...             ],
-        ...             separator=" ",
+        ...             [nw.col("a") * 2, nw.col("b"), nw.col("c")], separator=" "
         ...         ).alias("full_sentence")
         ...     )
         ... )
