@@ -1,8 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-from typing import Any
-from typing import Mapping
+from typing import TYPE_CHECKING, Any, Mapping
 
 import numpy as np
 import pytest
