@@ -485,7 +485,7 @@ def test_datetime_w_tz_duckdb() -> None:
 
 
 def test_datetime_w_tz_pyspark(constructor: Constructor) -> None:  # pragma: no cover
-    if "pyspark" not in str(constructor):
+    if "pyspark" not in str(constructor) or "sqlframe" in str(constructor):
         pytest.skip()
     pytest.importorskip("pyspark")
     pytest.importorskip("zoneinfo")
