@@ -4,35 +4,27 @@ import re
 import string
 from dataclasses import dataclass
 from itertools import chain
-from typing import TYPE_CHECKING
-from typing import Any
-from typing import Callable
-from typing import Iterable
-from typing import Iterator
-from typing import Protocol
-from typing import cast
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Iterator, Protocol, cast
 
 import hypothesis.strategies as st
 import pandas as pd
 import pyarrow as pa
 import pytest
 from hypothesis import given
-from pandas.testing import assert_frame_equal
-from pandas.testing import assert_index_equal
-from pandas.testing import assert_series_equal
+from pandas.testing import assert_frame_equal, assert_index_equal, assert_series_equal
 
 import narwhals as nw
 import narwhals.stable.v1 as nw_v1
-from narwhals.exceptions import ColumnNotFoundError
-from narwhals.utils import Implementation
-from narwhals.utils import Version
-from narwhals.utils import _DeferredIterable
-from narwhals.utils import check_column_exists
-from narwhals.utils import deprecate_native_namespace
-from narwhals.utils import parse_version
-from narwhals.utils import requires
-from tests.utils import PANDAS_VERSION
-from tests.utils import get_module_version_as_tuple
+from narwhals.utils import (
+    Implementation,
+    Version,
+    _DeferredIterable,
+    check_columns_exist,
+    deprecate_native_namespace,
+    parse_version,
+    requires,
+)
+from tests.utils import PANDAS_VERSION, get_module_version_as_tuple
 
 if TYPE_CHECKING:
     from types import ModuleType
@@ -94,10 +86,7 @@ def test_maybe_align_index_polars() -> None:
         nw_v1.maybe_align_index(df, s[1:])
 
 
-@pytest.mark.parametrize(
-    "column_names",
-    ["b", ["a", "b"]],
-)
+@pytest.mark.parametrize("column_names", ["b", ["a", "b"]])
 def test_maybe_set_index_pandas_column_names(
     column_names: str | list[str] | None,
 ) -> None:
@@ -107,13 +96,7 @@ def test_maybe_set_index_pandas_column_names(
     assert_frame_equal(nw_v1.to_native(result), expected)
 
 
-@pytest.mark.parametrize(
-    "column_names",
-    [
-        "b",
-        ["a", "b"],
-    ],
-)
+@pytest.mark.parametrize("column_names", ["b", ["a", "b"]])
 def test_maybe_set_index_polars_column_names(
     column_names: str | list[str] | None,
 ) -> None:
@@ -138,10 +121,7 @@ def test_maybe_set_index_polars_column_names(
                 nw_v1.from_native(pd.Series([0, 1, 2]), series_only=True),
                 nw_v1.from_native(pd.Series([1, 2, 0]), series_only=True),
             ],
-            [
-                pd.Series([0, 1, 2]),
-                pd.Series([1, 2, 0]),
-            ],
+            [pd.Series([0, 1, 2]), pd.Series([1, 2, 0])],
         ),
     ],
 )
@@ -310,8 +290,7 @@ def test_generate_temporary_column_name_raise() -> None:
     columns = [
         "".join(t)
         for t in product(
-            string.ascii_lowercase + string.digits,
-            string.ascii_lowercase + string.digits,
+            string.ascii_lowercase + string.digits, string.ascii_lowercase + string.digits
         )
     ]
 
@@ -337,22 +316,26 @@ def test_parse_version(
     assert parse_version(version) == expected
 
 
-def test_check_column_exists() -> None:
+def test_check_columns_exists() -> None:
     columns = ["a", "b", "c"]
     subset = ["d", "f"]
-    with pytest.raises(
-        ColumnNotFoundError,
-        match=re.escape("Column(s) ['d', 'f'] not found in ['a', 'b', 'c']"),
-    ):
-        check_column_exists(columns, subset)
+    error = check_columns_exist(subset, available=columns)
+    assert error is not None
+    assert str(error) == (
+        "The following columns were not found: ['d', 'f']\n\nHint: Did you mean one of these columns: ['a', 'b', 'c']?"
+    )
+
+    # Check that the error is not returned
+    subset = ["a", "b"]
+    error = check_columns_exist(subset, available=columns)
+    assert error is None
 
 
 def test_not_implemented() -> None:
     pytest.importorskip("polars")
 
     from narwhals._arrow.expr import ArrowExpr
-    from narwhals._polars.expr import PolarsExpr
-    from narwhals._polars.expr import PolarsExprStringNamespace
+    from narwhals._polars.expr import PolarsExpr, PolarsExprStringNamespace
     from narwhals.utils import not_implemented
 
     data: dict[str, Any] = {"foo": [1, 2], "bar": [6.0, 7.0]}
